function distance = distance(x1, y1, x2, y2)
%distance computes the distance between two points
%
% comsumes:
%    x1: number, x-coordinate of first point
%    y1: number, y-coordinate of first point
%    x2: number, x-coordinate of second point
%    y2: number, y-coordinate of second point
% produces:
%    distance: number, distance between the two points
%
% examples
%    >> distance(2, 3, 6, 12)
%    ans = 9.85
%    >> distance(12, 4, 7, 18)
%    ans = 14.87
%
% Caitlin Pretz CISC106 lab04 080, 09/18/07

   distance = sqrt((x2-x1)^2 + (y2-y1)^2);
   return;
   end


